@@ -143,7 +143,7 @@ sub _generate_p_method {
   };
 }
 
-sub _process_exec              { shift; +[@_] }
+sub _process__exec             { shift; +[@_] }
 sub _process_geohash           { shift; +[@_] }
 sub _process_geopos            { shift; +{lng => shift, lat => shift} }
 sub _process_georadius         { shift; +[@_] }
@@ -223,6 +223,9 @@ Mojo::Redis::Database - Execute basic redis commands
   # Promises
   $db->get_p("foo")->then(sub { my ($res) = @_; say "foo=$res" });
 
+See L<https://github.com/jhthorsen/mojo-redis/blob/master/examples/twitter.pl>
+for example L<Mojolicious> application.
+
 =head1 DESCRIPTION
 
 L<Mojo::Redis::Database> has methods for sending and receiving structured
